@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '1.009';
+our $VERSION = '1.013';
 
 sub new {
 	my ($class) = @_;
@@ -16,9 +16,8 @@ sub PT::Lang::X {
     my ($class) = @_;
 
     my $code = 'use strict;
-use warnings;
-use utf8;
-    ';
+		use warnings;
+		use utf8;';
 
     for my $element ( @{ $class->{Class}} ) {
         $code .= $element->X();
